@@ -30,9 +30,9 @@ class AES(object):
 		
 	def encrypt(self, raw):
 		if raw in ["", b"", None, False]:
-			return r3sponse.error_response("Can not encrypt null data.")
+			return r3sponse.error("Can not encrypt null data.")
 		response = self.get_key()
-		if not r3sponse.success(response): return response
+		if not response.success: return response
 		key = response["key"]
 		salt = response["salt"]
 		if isinstance(raw, bytes):
@@ -42,13 +42,13 @@ class AES(object):
 		cipher = _AES_.new(key, _AES_.MODE_CBC, iv)
 		encrypted = base64.b64encode(iv + salt + cipher.encrypt(raw.encode()))
 		if raw != b"" and encrypted == b"":
-			return r3sponse.error_response("Failed to encrypt the specified data with the current passphrase / salt.")
-		return r3sponse.success_response("Successfully encrypted the specified data.", {
+			return r3sponse.error("Failed to encrypt the specified data with the current passphrase / salt.")
+		return r3sponse.success("Successfully encrypted the specified data.", {
 			"encrypted":encrypted,
 		})
 	def decrypt(self, enc):
 		if enc in ["", b"", None, False]:
-			return r3sponse.error_response("Can not decrypt null data.")
+			return r3sponse.error("Can not decrypt null data.")
 		if isinstance(enc, str):
 			enc = enc.encode()
 		enc = base64.b64decode(enc)
@@ -56,13 +56,13 @@ class AES(object):
 		iv = iv_salt[:16]
 		salt = iv_salt[16:]
 		response = self.get_key(salt=salt)
-		if not r3sponse.success(response): return response
+		if not response.success: return response
 		key = response["key"]
 		cipher = _AES_.new(key, _AES_.MODE_CBC, iv)
 		decrypted = self.unpad(cipher.decrypt(enc[32:]))
 		if enc != b"" and decrypted == b"":
-			return r3sponse.error_response("Failed to decrypt the specified data with the current passphrase / salt.")
-		return r3sponse.success_response("Successfully decrypted the specified data.", {
+			return r3sponse.error("Failed to decrypt the specified data with the current passphrase / salt.")
+		return r3sponse.success("Successfully decrypted the specified data.", {
 			"decrypted":decrypted,
 		})
 	def get_key(self, salt=None):
@@ -72,7 +72,7 @@ class AES(object):
 			salt = salt.encode()
 		kdf = PBKDF2(self.passphrase, salt, 64, 1000)
 		key = kdf[:32]
-		return r3sponse.success_response("Successfully loaded the aes key.", {
+		return r3sponse.success("Successfully loaded the aes key.", {
 			"key":key,
 			"salt":salt,
 		})
@@ -80,7 +80,7 @@ class AES(object):
 		length=16
 		chars = ''.join([string.ascii_uppercase, string.ascii_lowercase, string.digits])
 		salt = ''.join(random.choice(chars) for x in range(length))
-		return r3sponse.success_response("Successfully generated a salt.", {
+		return r3sponse.success("Successfully generated a salt.", {
 			"salt":salt,
 		})
 
@@ -115,14 +115,14 @@ class AsymmetricAES(object):
 		passphrase = utils.__generate_shell_string__(characters=64, numerical_characters=True)
 		aes = AES(passphrase=passphrase)
 		response = aes.encrypt(string)
-		if not r3sponse.success(response): return response
+		if not response.success: return response
 		aes_encrypted = response["encrypted"]
 		if b" " in aes_encrypted:
-			return r3sponse.error_response("AES encrypt data contains invalid ' ' character(s).")
+			return r3sponse.error("AES encrypt data contains invalid ' ' character(s).")
 
 		# encrypt aes key with rsa.
 		response = self.rsa.encrypt_string(passphrase, decode=False)
-		if not r3sponse.success(response): return response
+		if not response.success: return response
 		rsa_encrypted = response["encrypted"]
 
 		# pack encrypted.
@@ -130,7 +130,7 @@ class AsymmetricAES(object):
 
 		# success.
 		if decode: encrypted = encrypted.decode()
-		return r3sponse.success_response("Successfully encrypted the specified data.", {
+		return r3sponse.success("Successfully encrypted the specified data.", {
 			"encrypted":encrypted
 		})
 
@@ -144,22 +144,22 @@ class AsymmetricAES(object):
 			key,encrypted = string.split(" ")
 		#except:
 		except KeyboardInterrupt:
-			return r3sponse.error_response("Unable to unpack the encrypted data.")
+			return r3sponse.error("Unable to unpack the encrypted data.")
 
 		# decypt key with rsa.
 		response = self.rsa.decrypt_string(key, decode=False)
-		if not r3sponse.success(response): return response
+		if not response.success: return response
 		passphrase = response["decrypted"].decode()
 
 		# decrypt with aes.
 		aes = AES(passphrase=passphrase)
 		response = aes.decrypt(encrypted)
-		if not r3sponse.success(response): return response
+		if not response.success: return response
 		decrypted = response["decrypted"]
 
 		# success.
 		if decode: decrypted = decrypted.decode()
-		return r3sponse.success_response("Successfully decrypted the specified data.", {
+		return r3sponse.success("Successfully decrypted the specified data.", {
 			"decrypted":decrypted
 		})
 
@@ -171,18 +171,18 @@ class AsymmetricAES(object):
 		response = r3sponse.check_parameters({
 			"input":input,
 			"output":output,})
-		if not r3sponse.success(response): return response
+		if not response.success: return response
 
 		# encrypt.
 		data = utils.__load_bytes__(input)
 		if base64_encoding:
 			data = base64.b64encode(data)
 		response = self.encrypt(data, decode=False)
-		if not r3sponse.success(response): return response
+		if not response.success: return response
 
 		# write out.
 		try: utils.__save_bytes__(output, response["encrypted"])
-		except: return r3sponse.success_response(f"Failed to write out encrypted file {output}.")
+		except: return r3sponse.error(f"Failed to write out encrypted file {output}.")
 
 		# remove.
 		if remove and input != output: 
@@ -190,7 +190,7 @@ class AsymmetricAES(object):
 			except PermissionError: os.system(f"sudo rm -fr {input}")
 
 		# handler.
-		return r3sponse.success_response(f"Successfully encrypted file {input} to {output}.")
+		return r3sponse.success(f"Successfully encrypted file {input} to {output}.")
 
 		#
 	def decrypt_file(self, input=None, output=None, remove=False, base64_encoding=False):
@@ -200,18 +200,18 @@ class AsymmetricAES(object):
 		response = r3sponse.check_parameters({
 			"input":input,
 			"output":output,})
-		if not r3sponse.success(response): return response
+		if not response.success: return response
 
 		# encrypt.
 		response = self.decrypt(utils.__load_bytes__(input), decode=False)
-		if not r3sponse.success(response): return response
+		if not response.success: return response
 
 		# write out.
 		decrypted = response.decrypted
 		if base64_encoding:
 			decrypted = base64.b64decode(decrypted)
 		try: utils.__save_bytes__(output, decrypted)
-		except: return r3sponse.success_response(f"Failed to write out decrypted file {output}.")
+		except: return r3sponse.error(f"Failed to write out decrypted file {output}.")
 
 		# remove.
 		if remove and input != output: 
@@ -219,7 +219,7 @@ class AsymmetricAES(object):
 			except PermissionError: os.system(f"sudo rm -fr {input}")
 
 		# handler.
-		return r3sponse.success_response(f"Successfully decrypted file {input} to {output}.")
+		return r3sponse.success(f"Successfully decrypted file {input} to {output}.")
 
 		#
 	def encrypt_directory(self, input=None, output=None, remove=False):
@@ -227,9 +227,9 @@ class AsymmetricAES(object):
 		# checks.
 		file_path = Formats.FilePath(input)
 		if not file_path.exists():
-			return r3sponse.error_response(f"Directory [{input}] does not exist.")
+			return r3sponse.error(f"Directory [{input}] does not exist.")
 		if not file_path.directory():
-			return r3sponse.error_response(f"Directory path [{input}] is not a directory.")
+			return r3sponse.error(f"Directory path [{input}] is not a directory.")
 
 		# zip path.
 		if output == None:
@@ -237,13 +237,13 @@ class AsymmetricAES(object):
 			else: zip_path = str(input)
 			zip_path = f'{zip_path}.enc.zip'
 		elif ".enc.zip" not in output:
-			return r3sponse.error_response(f"Invalid output format [{output}], the format must end with [***.enc.zip]")
+			return r3sponse.error(f"Invalid output format [{output}], the format must end with [***.enc.zip]")
 		else:
 			zip_path = output
 
 		# check output.
 		if os.path.exists(zip_path):
-			return r3sponse.error_response(f"output path [{zip_path}] already exists.")
+			return r3sponse.error(f"output path [{zip_path}] already exists.")
 
 		# create zip.
 		zip = Files.Zip(path=zip_path)
@@ -257,10 +257,10 @@ class AsymmetricAES(object):
 					os.system(f"rm -fr {input}")
 					if os.path.exists(input): raise PermissionError("")
 				except PermissionError: os.system(f"sudo rm -fr {input}")
-			return r3sponse.success_response(f"Successfully encrypted directory [{input}].")
+			return r3sponse.success(f"Successfully encrypted directory [{input}].")
 		else:
 			zip.file_path.delete(forced=True)
-			return r3sponse.error_response(f"Failed to encrypt directory [{input}].")
+			return r3sponse.error(f"Failed to encrypt directory [{input}].")
 
 		#
 	def decrypt_directory(self, input=None, output=None, remove=False):
@@ -268,32 +268,32 @@ class AsymmetricAES(object):
 		# checks.
 		file_path = Formats.FilePath(input)
 		if not file_path.exists():
-			return r3sponse.error_response(f"Input [{input}] does not exist.")
+			return r3sponse.error(f"Input [{input}] does not exist.")
 		if file_path.directory():
-			return r3sponse.error_response(f"Input path [{input}] is a directory.")
+			return r3sponse.error(f"Input path [{input}] is a directory.")
 
 		# dir path.
 		if output == None:
 			if ".enc.zip" not in input:
-				return r3sponse.error_response(f"Invalid input format [{input}], the format must end with [***.enc.zip]")
+				return r3sponse.error(f"Invalid input format [{input}], the format must end with [***.enc.zip]")
 			dir_path = output.replace(".enc.zip", "/").replace("//","/").replace("//","/").replace("//","/")
 		else:
 			if ".enc.zip" in output:
-				return r3sponse.error_response(f"Invalid output format [{output}], the format can not end with [***.enc.zip]")
+				return r3sponse.error(f"Invalid output format [{output}], the format can not end with [***.enc.zip]")
 			dir_path = output.replace(".enc.zip", "/")
 
 		# check output.
 		l_dir_path = dir_path
 		if l_dir_path[len(l_dir_path)-1] == "/": l_dir_path = l_dir_path[:-1]
 		if os.path.exists(l_dir_path):
-			return r3sponse.error_response(f"Output path [{l_dir_path}] already exists.")
+			return r3sponse.error(f"Output path [{l_dir_path}] already exists.")
 		
 		# decrypt zip.
 		tmp_zip = f"/tmp/{Formats.FilePath(input).name()}"
 		if os.path.exists(tmp_zip): os.system(f"rm -fr {tmp_zip}")
 		response = self.decrypt_file(input=input, output=tmp_zip, remove=False, base64_encoding=True)
 		if not response.success:
-			return r3sponse.error_response(f"Failed to decrypted directory [{input}], error: {response.error}")
+			return r3sponse.error(f"Failed to decrypted directory [{input}], error: {response.error}")
 
 		# extract zip.
 		tmp_extract = f"/tmp/{Formats.String('').generate(length=32,capitalize=True,digits=True)}/"
@@ -310,15 +310,15 @@ class AsymmetricAES(object):
 				if remove and input != output:
 					try: os.remove(input)
 					except PermissionError: os.system(f"sudo rm -fr {input}")
-				return r3sponse.success_response(f"Successfully decrypted directory [{input}].")
+				return r3sponse.success(f"Successfully decrypted directory [{input}].")
 			else:
 				os.system(f"rm -fr {tmp_extract}")
 				os.system(f"rm -fr {tmp_zip}")
-				return r3sponse.error_response(f"Failed to decrypt directory [{input}].")
+				return r3sponse.error(f"Failed to decrypt directory [{input}].")
 		else:
 			os.system(f"rm -fr {tmp_extract}")
 			os.system(f"rm -fr {tmp_zip}")
-			return r3sponse.error_response(f"Failed to decrypt directory [{input}].")
+			return r3sponse.error(f"Failed to decrypt directory [{input}].")
 
 		#
 
@@ -352,21 +352,21 @@ class Database(object):
 
 		# check sample.
 		if not os.path.exists(f"{self.path}.passphrase"):
-			response = self.aes.encrypt(self.aes.passphrase)
+			response = self.aes.encrypt(self.aes.rsa.passphrase)
 			if not response.success: return response
 			try: utils.__save_bytes__(f"{self.path}.passphrase", response.encrypted)
-			except: return r3sponse.error_response(f"Failed to write out encrypted passphrase {self.path}.passphrase")
+			except: return r3sponse.error(f"Failed to write out encrypted passphrase {self.path}.passphrase")
 		else:
 			try: passphrase = utils.__load_bytes__(f"{self.path}.passphrase")
-			except: return r3sponse.error_response(f"Failed to load encrypted passphrase {self.path}.passphrase")
+			except: return r3sponse.error(f"Failed to load encrypted passphrase {self.path}.passphrase")
 			response = self.aes.decrypt(passphrase)
 			if not response.success: return response
-			if response.decrypted.decode().replace("\n","") != self.aes.passphrase.replace("\n",""):
-				return r3sponse.error_response("Specified an incorrect passphrase.")
+			if response.decrypted.decode().replace("\n","") != self.aes.rsa.passphrase.replace("\n",""):
+				return r3sponse.error("Specified an incorrect passphrase.")
 
 		# success.
 		self.activated = True
-		return r3sponse.success_response(f"Successfully activated encrypted database {self.path}.")
+		return r3sponse.success(f"Successfully activated encrypted database {self.path}.")
 
 		#
 	def check(self, 
@@ -377,7 +377,7 @@ class Database(object):
 		# save the changes.
 		save=True,
 	):
-		if not self.activated: return r3sponse.error_response(f"Encrypted database {self.path} is not activated yet, call database.activate() first.")
+		if not self.activated: return r3sponse.error(f"Encrypted database {self.path} is not activated yet, call database.activate() first.")
 		response = r3sponse.check_parameters({
 			"path:str":path,
 			"default:str,dict,list,int,float":default,
@@ -386,34 +386,34 @@ class Database(object):
 		content = self.DataObject(path=f"{self.path}/{path}", aes=self.aes)
 		response = content.check(default=default, save=save)
 		if not response.success: return response
-		return r3sponse.success_response(f"Successfully checked content {path}.", {
+		return r3sponse.success(f"Successfully checked content {path}.", {
 			"content":content,
 		})
 	def load(self, 
 		# the subpath of the content (! param number 1).
 		path=None, 
 	):
-		if not self.activated: return r3sponse.error_response(f"Encrypted database {self.path} is not activated yet, call database.activate() first.")
+		if not self.activated: return r3sponse.error(f"Encrypted database {self.path} is not activated yet, call database.activate() first.")
 		response = r3sponse.check_parameters({
 			"path:str":path,})
 		if not response.success: return response
 		content = self.DataObject(path=f"{self.path}/{path}", aes=self.aes)
 		response = content.load()
 		if not response.success: return response
-		return r3sponse.success_response(f"Successfully loaded content {path}.", {
+		return r3sponse.success(f"Successfully loaded content {path}.", {
 			"content":content,
 		})
 	def save(self, 
 		# the content object (! param number 1).
 		content=None,
 	):
-		if not self.activated: return r3sponse.error_response(f"Encrypted database {self.path} is not activated yet, call database.activate() first.")
+		if not self.activated: return r3sponse.error(f"Encrypted database {self.path} is not activated yet, call database.activate() first.")
 		response = r3sponse.check_parameters({
 			"content:object":content,})
 		if not response.success: return response
 		response = content.save()
 		if not response.success: return response
-		return r3sponse.success_response(f"Successfully saved content {path}.")
+		return r3sponse.success(f"Successfully saved content {path}.")
 	
 	# a data object.
 	class DataObject(object):
@@ -439,7 +439,7 @@ class Database(object):
 			response = r3sponse.check_parameters({
 				"default:dict,list,str,float,int":default,
 				"save:bool":save,})
-			if not r3sponse.success(response): return response
+			if not response.success: return response
 			if not os.path.exists(self.base): os.system(f"mkdir -p {self.base}")
 			do = False
 			if not os.path.exists(self.path): 
@@ -447,11 +447,11 @@ class Database(object):
 				new = default
 			else:
 				response = self.load()
-				if not r3sponse.success(response): return response
+				if not response.success: return response
 				old_format = Formats.get(self.content, serialize=True)
 				new_format = Formats.get(default, serialize=True)
 				if old_format != new_format:
-					return r3sponse.error_response(f"Mismatching formats, old format: {old_format}, new format: {new_format}.")
+					return r3sponse.error(f"Mismatching formats, old format: {old_format}, new format: {new_format}.")
 				if new_format == "dict":
 					old = dict(self.content)
 					new = Files.Dictionary(path=False, dictionary=old).check(default=default, save=False)
@@ -466,7 +466,7 @@ class Database(object):
 					old = str(self.content)
 					new = str(default)
 					if new != old: do = True
-				else: return r3sponse.error_response(f"Unsupported new format: {new_format}.")
+				else: return r3sponse.error(f"Unsupported new format: {new_format}.")
 			if do:
 				self.content = new
 				self.format = Formats.get(self.content, serialize=True)
@@ -474,12 +474,12 @@ class Database(object):
 					self.loaded = True
 					response = self.save()
 					if not response.success: return response
-			return r3sponse.success_response(f"Successfully checked the content of {self.path}.")
+			return r3sponse.success(f"Successfully checked the content of {self.path}.")
 		# load & decrypt.
 		def load(self):
 			try:
 				content = utils.__load_file__(self.path)
-			except Exception as e: return r3sponse.error_response(f"Failed to load content {self.path}, {e}.")
+			except Exception as e: return r3sponse.error(f"Failed to load content {self.path}, {e}.")
 			format, content = content.split(" ")
 			response = self.aes.decrypt(content.encode())
 			if not response.success: return response
@@ -487,32 +487,32 @@ class Database(object):
 			if format in ["dict", "list"]:
 				try:
 					content = json.loads(decrypted)
-				except Exception as e: return r3sponse.error_response(f"Failed to serialize content {self.path}, {e}.")
+				except Exception as e: return r3sponse.error(f"Failed to serialize content {self.path}, {e}.")
 			elif format in ["int"]:
 				try:
 					content = int(decrypted)
-				except Exception as e: return r3sponse.error_response(f"Failed to serialize content {self.path}, {e}.")
+				except Exception as e: return r3sponse.error(f"Failed to serialize content {self.path}, {e}.")
 			elif format in ["float"]:
 				try:
 					content = float(decrypted)
-				except Exception as e: return r3sponse.error_response(f"Failed to serialize content {self.path}, {e}.")
+				except Exception as e: return r3sponse.error(f"Failed to serialize content {self.path}, {e}.")
 			elif format in ["str"]:
 				try:
 					content = str(decrypted)
-				except Exception as e: return r3sponse.error_response(f"Failed to serialize content {self.path}, {e}.")
-			else: return r3sponse.error_response(f"Unsupported format: {format}.")
+				except Exception as e: return r3sponse.error(f"Failed to serialize content {self.path}, {e}.")
+			else: return r3sponse.error(f"Unsupported format: {format}.")
 			self.content = content
 			self.format = format
 			self.loaded = True
-			return r3sponse.success_response(f"Successfully loaded content {self.path}.")
+			return r3sponse.success(f"Successfully loaded content {self.path}.")
 		# save & encrypt.
 		def save(self):
 			if not self.loaded:
-				return r3sponse.error_response("The data object is not loaded yet, you must call content.load() first.")
+				return r3sponse.error("The data object is not loaded yet, you must call content.load() first.")
 			if self.format in ["list", "dict"]:
 				try:
 					content = json.dumps(self.content)
-				except Exception as e: return r3sponse.error_response(f"Failed to dump content {self.path}, {e}.")
+				except Exception as e: return r3sponse.error(f"Failed to dump content {self.path}, {e}.")
 			elif self.format in ["str", "int", "float"]:
 				content = str(self.content)
 			else:
@@ -521,8 +521,8 @@ class Database(object):
 			if not response.success: return response
 			try:
 				content = utils.__save_bytes__(self.path, f"{self.format} ".encode()+response.encrypted)
-			except Exception as e: return r3sponse.error_response(f"Failed to save content {self.path}, {e}.")
-			return r3sponse.success_response(f"Successfully saved content {self.path}.")
+			except Exception as e: return r3sponse.error(f"Failed to save content {self.path}, {e}.")
+			return r3sponse.success(f"Successfully saved content {self.path}.")
 		# iterate over self keys & variables.
 		def items(self):
 			if not self.loaded: raise ValueError("Load the content object first.")
