@@ -11,7 +11,7 @@ from Crypto.PublicKey import RSA as _RSA_
 from Crypto.Cipher import PKCS1_OAEP
 
 # inc imports.
-from fil3s import Files, Formats
+from fil3s import *
 
 # the encryption class.
 class RSA(object):
@@ -64,13 +64,13 @@ class RSA(object):
 
 		# checks.
 		if not self.memory:
-			if log_level >= 0: loader = system.console.Loader(f"Generating key {self.directory}")
+			if log_level >= 0: loader = syst3m.console.Loader(f"Generating key {self.directory}")
 			if os.path.exists(directory): 
 				response["error"] = f"Key [{directory}] already exists."
 				return response
 		else:
-			if log_level >= 0: loader = system.console.Loader("Generating key")
-			
+			if log_level >= 0: loader = syst3m.console.Loader("Generating key")
+		
 		# generate.
 		key_pair = _RSA_.generate(4096, e=65537)
 		public_key = key_pair.publickey()
@@ -89,10 +89,9 @@ class RSA(object):
 			utils.__set_file_path_permission__(directory, permission=700)
 			utils.__set_file_path_permission__(private_key_path, permission=600)
 			utils.__set_file_path_permission__(public_key_path, permission=644)
-			
 		# response.
 		loader.stop()
-		return r3sponse.success_response(f"Successfully generated key {directory}.", {
+		return r3sponse.success(f"Successfully generated key {directory}.", {
 			"private_key":private_key_pem.decode(),
 			"public_key":public_key_pem.decode(),
 		})
@@ -105,6 +104,10 @@ class RSA(object):
 		if not self.memory:
 			self.private_key_data = utils.__load_file__(self.private_key)
 			self.public_key_data = utils.__load_file__(self.public_key)
+		else:
+			self.private_key_data = self.private_key
+			self.public_key_data = self.public_key
+
 
 		# initialize keys.
 		if self.passphrase == None:
@@ -118,7 +121,7 @@ class RSA(object):
 				return response
 		else:
 			try:
-				self.public_key_object = _RSA_.importKey(self.public_key_data, passphrase=self.passphrase)
+				self.public_key_object = _RSA_.importKey(self.public_key_data)
 				self.private_key_object = _RSA_.importKey(self.private_key_data, passphrase=self.passphrase)
 			except ValueError as e:
 				if "Padding is incorrect" in str(e):
@@ -127,7 +130,7 @@ class RSA(object):
 				return response
 		
 		# response.
-		return r3sponse.success_response("Successfully loaded the key pair.")
+		return r3sponse.success("Successfully loaded the key pair.")
 
 		#
 	def load_public_key(self):
@@ -136,27 +139,20 @@ class RSA(object):
 		response = utils.__default_response__()
 		if not self.memory:
 			self.public_key_data = utils.__load_file__(self.public_key)
+		else:
+			self.public_key_data = self.public_key
 
 		# initialize keys.
-		if self.passphrase == None:
-			try:
-				self.public_key_object = _RSA_.importKey(self.public_key_data)
-			except ValueError as e:
-				if "Padding is incorrect" in str(e):
-					response["error"] = "Provided an incorrect passphrase."
-				else: response["error"] = f"ValueError: {e}"
-				return response
-		else:
-			try:
-				self.public_key_object = _RSA_.importKey(self.public_key_data, passphrase=self.passphrase)
-			except ValueError as e:
-				if "Padding is incorrect" in str(e):
-					response["error"] = "Provided an incorrect passphrase."
-				else: response["error"] = f"ValueError: {e}"
-				return response
+		try:
+			self.public_key_object = _RSA_.importKey(self.public_key_data)
+		except ValueError as e:
+			if "Padding is incorrect" in str(e):
+				response["error"] = "Provided an incorrect passphrase."
+			else: response["error"] = f"ValueError: {e}"
+			return response
 		
 		# response.
-		return r3sponse.success_response("Successfully loaded the key pair.")
+		return r3sponse.success("Successfully loaded the key pair.")
 
 		#
 	def load_private_key(self):
@@ -165,6 +161,8 @@ class RSA(object):
 		response = utils.__default_response__()
 		if not self.memory:
 			self.private_key_data = utils.__load_file__(self.private_key)
+		else:
+			self.private_key_data = self.private_key
 
 		# initialize keys.
 		if self.passphrase == None:
@@ -185,7 +183,7 @@ class RSA(object):
 				return response
 		
 		# response.
-		return r3sponse.success_response("Successfully loaded the key pair.")
+		return r3sponse.success("Successfully loaded the key pair.")
 
 		#
 	def edit_passphrase(self, passphrase=None):
@@ -229,7 +227,7 @@ class RSA(object):
 		if layers-1 > 0:
 			return self.encrypt_file(path, layers=layers-1)
 		else:
-			return r3sponse.success_response(f"Successfully encrypted file [{path}].")
+			return r3sponse.success(f"Successfully encrypted file [{path}].")
 
 		#
 	def encrypt_directory(self, path, recursive=False, layers=1):
@@ -255,7 +253,7 @@ class RSA(object):
 			if layers-1 > 0:
 				return self.encrypt_directory(path, recursive=True, layers=layers-1)
 			else:
-				return r3sponse.success_response(f"Successfully encrypted directory [{path}] (recursively).")
+				return r3sponse.success(f"Successfully encrypted directory [{path}] (recursively).")
 
 
 		# encrypt the directory and save to x.encrypted.zip file.
